<?php
class ConnectionManager_Base
{
	/**
	 * Cached Connection objects
	 * @type Array
	 */
	protected $cache = array();

	/**
	 * Project connections data
	 * @type Array
	 */
	protected $_connectionsData;

	/**
	 * Project connections data
	 * @type Array
	 */
	protected $_connectionsIdByName = array();


	/**
	 * An array storing the correspondence between project
	 * datasource tables names and connections ids
	 * @type Array
	 */
	protected $_tablesConnectionIds;


	/**
	 * @constructor
	 */
	function __construct()
	{
		$this->_setConnectionsData();
		$this->_setTablesConnectionIds();
	}

	/**
	 * Get connection id by the table name
	 * @param String tName
	 * @return Connection
	 */
	public function getTableConnId( $tName )
	{
		return $this->_tablesConnectionIds[ $tName ];
	}


	/**
	 * Get connection object by the table name
	 * @param String tName
	 * @return Connection
	 */
	public function byTable( $tName )
	{
		$connId = $this->_tablesConnectionIds[ $tName ];
		if( !$connId )
			return $this->getDefault();
		return $this->byId( $connId );
	}

	/**
	 * Get connection object by the connection name
	 * @param String connName
	 * @return Connection
	 */
	public function byName( $connName )
	{
		$connId = $this->getIdByName( $connName );
		if( !$connId )
			return $this->getDefault();
		return $this->byId( $connId );
	}

	/**
	 * Get connection id by the connection name
	 * @param String connName
	 * @return String
	 */
	protected function getIdByName( $connName )
	{
		return $this->_connectionsIdByName[ $connName ];
	}

	/**
	 * Get connection object by the connection id
	 * @param String connId
	 * @return Connection
	 */
	public function byId( $connId )
	{
		if( !isset( $this->cache[ $connId ] ) ) {
			$conn = $this->getConnection( $connId );
			if( !$conn ) {
				global $restApis;
				$conn = $restApis->getConnection( $connId );
			}
			if( !$conn ) {
				$conn = $this->getDefault();
			}
			$this->cache[ $connId ] = $conn;
		}

		return $this->cache[ $connId ];
	}

	/**
	 * Get the default db connection class
	 * @return Connection
	 */
	public function getDefault()
	{
		return $this->byId( "erp_test3_at_localhost" );
	}

	/**
	 * Get the default db connection id
	 * @return String
	 */
	public function getDefaultConnId()
	{
		return "erp_test3_at_localhost";
	}



	/**
	 * Get the users table db connection
	 * @return Connection
	 */
	public function getForLogin() {
		return $this->byId( $this->getLoginConnId() );
	}

	public function getLoginConnId() {
		return "erp_test3_at_localhost";
	}


	/**
	 * Get the log table db connection
	 * @return Connection
	 */
	public function getForAudit()
	{
		return $this->getDefault();
	}

	/**
	 * Get the locking table db connection
	 * @return Connection
	 */
	public function getForLocking()
	{
		return $this->getDefault();
	}

	/**
	 * Get the 'ug_groups' table db connection
	 * @return Connection
	 */
	public function getForUserGroups() {
		return $this->byId( $this->getUserGroupsConnId() );
	}

	public function getUserGroupsConnId() {
		return "erp_test3_at_localhost";
	}

	/**
	 * Get the saved searches table db connection
	 * @return Connection
	 */
	public function getForSavedSearches()
	{
		return $this->byId( $this->getSavedSearchesConnId() );
	}
	
	/**
	 * Get the saved searches table db connection
	 * @return Connection
	 */
	public function getSavedSearchesConnId()
	{
		return "erp_test3_at_localhost";
	}	

	/**
	 * Get the webreports tables db connection
	 * @return Connection
	 */
	public function getForWebReports() 
	{
		return $this->byId( $this->getSavedSearchesConnId() );
	}

	/**
	 * Get the webreports tables db connection id
	 * @return String
	 */
	public function getWebReportsConnId() {
		return "erp_test3_at_localhost";
	}	
	
	/**
	 * @param String connId
	 * @return Connection
	 */
	protected function getConnection( $connId )
	{
		return false;
	}

	public function getConectionsIds()
	{
		$connectionsIds = array();
		foreach ($this->_connectionsData as $connId => $data) {
			$connectionsIds[] = $connId;
		}

		return $connectionsIds;
	}

	/**
	 * Set the data representing the project's
	 * db connection properties
	 */
	protected function _setConnectionsData()
	{
        return null;
	}

	/**
	 * Set the data representing the correspondence between
	 * the project's table names and db connections
	 */
	protected function _setTablesConnectionIds()
	{
		$connectionsIds = array();
		$connectionsIds["attendance_summary"] = "erp_test3_at_localhost";
		$connectionsIds["employees"] = "erp_test3_at_localhost";
		$connectionsIds["process_payroll_detail"] = "erp_test3_at_localhost";
		$connectionsIds["executive_manangement"] = "erp_test3_at_localhost";
		$connectionsIds["company_info"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_item"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_entry"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_entry_detail"] = "erp_test3_at_localhost";
		$connectionsIds["cost_center"] = "erp_test3_at_localhost";
		$connectionsIds["process_payroll_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["process_payroll_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["process_payroll_detail_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["process_payroll_detail_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_entry_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_entry_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_entry_detail_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_entry_detail_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["bio_upload"] = "erp_test3_at_localhost";
		$connectionsIds["attendance"] = "erp_test3_at_localhost";
		$connectionsIds["attendance_type"] = "erp_test3_at_localhost";
		$connectionsIds["schedule"] = "erp_test3_at_localhost";
		$connectionsIds["department"] = "erp_test3_at_localhost";
		$connectionsIds["position"] = "erp_test3_at_localhost";
		$connectionsIds["recuring_benefits"] = "erp_test3_at_localhost";
		$connectionsIds["recuring_deductions"] = "erp_test3_at_localhost";
		$connectionsIds["business_partner"] = "erp_test3_at_localhost";
		$connectionsIds["applicant_requirements"] = "erp_test3_at_localhost";
		$connectionsIds["employee_requirements"] = "erp_test3_at_localhost";
		$connectionsIds["gov_or_payments"] = "erp_test3_at_localhost";
		$connectionsIds["gov_or_records"] = "erp_test3_at_localhost";
		$connectionsIds["accident"] = "erp_test3_at_localhost";
		$connectionsIds["employees_payroll_setup"] = "erp_test3_at_localhost";
		$connectionsIds["employee_dependents"] = "erp_test3_at_localhost";
		$connectionsIds["over_time"] = "erp_test3_at_localhost";
		$connectionsIds["leave"] = "erp_test3_at_localhost";
		$connectionsIds["undertime"] = "erp_test3_at_localhost";
		$connectionsIds["change_time"] = "erp_test3_at_localhost";
		$connectionsIds["fieldwork"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_account_type"] = "erp_test3_at_localhost";
		$connectionsIds["bank"] = "erp_test3_at_localhost";
		$connectionsIds["sss"] = "erp_test3_at_localhost";
		$connectionsIds["pagibig"] = "erp_test3_at_localhost";
		$connectionsIds["annual_tax_table"] = "erp_test3_at_localhost";
		$connectionsIds["holiday"] = "erp_test3_at_localhost";
		$connectionsIds["philhealth"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_report_center"] = "erp_test3_at_localhost";
		$connectionsIds["employment_history"] = "erp_test3_at_localhost";
		$connectionsIds["tranasactions_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["approver_list"] = "erp_test3_at_localhost";
		$connectionsIds["Fieldwork_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["employee_project"] = "erp_test3_at_localhost";
		$connectionsIds["employee_project_task"] = "erp_test3_at_localhost";
		$connectionsIds["activity_log"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_system_user"] = "erp_test3_at_localhost";
		$connectionsIds["chart_of_accounts"] = "erp_test3_at_localhost";
		$connectionsIds["request_for_payment"] = "erp_test3_at_localhost";
		$connectionsIds["request_for_payment_detail"] = "erp_test3_at_localhost";
		$connectionsIds["recurring_benefits_detail"] = "erp_test3_at_localhost";
		$connectionsIds["recurring_deductions_detail"] = "erp_test3_at_localhost";
		$connectionsIds["Training_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Seminar_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Accident_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Employment_History_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Overtime_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["Overtime_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Undertime_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Undertime_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["Change_Time_Schedule_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Change_Time_Schedule_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["item"] = "erp_test3_at_localhost";
		$connectionsIds["uom"] = "erp_test3_at_localhost";
		$connectionsIds["vat_type"] = "erp_test3_at_localhost";
		$connectionsIds["vat_rate"] = "erp_test3_at_localhost";
		$connectionsIds["phase"] = "erp_test3_at_localhost";
		$connectionsIds["Leave_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["Leave_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["currency"] = "erp_test3_at_localhost";
		$connectionsIds["credit_terms"] = "erp_test3_at_localhost";
		$connectionsIds["discounts"] = "erp_test3_at_localhost";
		$connectionsIds["purchase_request"] = "erp_test3_at_localhost";
		$connectionsIds["purchase_request_detail"] = "erp_test3_at_localhost";
		$connectionsIds["currency_exchange_rate"] = "erp_test3_at_localhost";
		$connectionsIds["Purchase_Request_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Purchase_Request_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["purchase_request_detail_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["purchase_request_detail_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["request_for_payment_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["request_for_payment_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["request_for_payment_detail_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["request_for_payment_detail_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["accounting_period"] = "erp_test3_at_localhost";
		$connectionsIds["fiscal_year"] = "erp_test3_at_localhost";
		$connectionsIds["account_classification"] = "erp_test3_at_localhost";
		$connectionsIds["financial_statement"] = "erp_test3_at_localhost";
		$connectionsIds["account_type"] = "erp_test3_at_localhost";
		$connectionsIds["account_general_classification"] = "erp_test3_at_localhost";
		$connectionsIds["reimbursement"] = "erp_test3_at_localhost";
		$connectionsIds["reimbursement_detail"] = "erp_test3_at_localhost";
		$connectionsIds["system_user"] = "erp_test3_at_localhost";
		$connectionsIds["serial_no"] = "erp_test3_at_localhost";
		$connectionsIds["change_password"] = "erp_test3_at_localhost";
		$connectionsIds["aging_ap"] = "erp_test3_at_localhost";
		$connectionsIds["Birthday_Reminder"] = "erp_test3_at_localhost";
		$connectionsIds["check_formats"] = "erp_test3_at_localhost";
		$connectionsIds["Missing_log"] = "erp_test3_at_localhost";
		$connectionsIds["upcomming_holiday"] = "erp_test3_at_localhost";
		$connectionsIds["tax_status"] = "erp_test3_at_localhost";
		$connectionsIds["Loan_types"] = "erp_test3_at_localhost";
		$connectionsIds["Other_Benefits"] = "erp_test3_at_localhost";
		$connectionsIds["Other_Deductions"] = "erp_test3_at_localhost";
		$connectionsIds["Leave_types"] = "erp_test3_at_localhost";
		$connectionsIds["employee_recurring_benefit_detail"] = "erp_test3_at_localhost";
		$connectionsIds["employee_recurring_deduction_detail"] = "erp_test3_at_localhost";
		$connectionsIds["section"] = "erp_test3_at_localhost";
		$connectionsIds["overtime_detail"] = "erp_test3_at_localhost";
		$connectionsIds["leave_detail"] = "erp_test3_at_localhost";
		$connectionsIds["change_time_detail"] = "erp_test3_at_localhost";
		$connectionsIds["fieldwork_detail"] = "erp_test3_at_localhost";
		$connectionsIds["changetime_file"] = "erp_test3_at_localhost";
		$connectionsIds["changetime_file_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["changetime_file_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["fieldwork_file"] = "erp_test3_at_localhost";
		$connectionsIds["attendance_logs"] = "erp_test3_at_localhost";
		$connectionsIds["Supplier"] = "erp_test3_at_localhost";
		$connectionsIds["Fieldwork_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["witholding"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_terms"] = "erp_test3_at_localhost";
		$connectionsIds["violation"] = "erp_test3_at_localhost";
		$connectionsIds["violation_type"] = "erp_test3_at_localhost";
		$connectionsIds["loan"] = "erp_test3_at_localhost";
		$connectionsIds["loan__detail"] = "erp_test3_at_localhost";
		$connectionsIds["leave_credits"] = "erp_test3_at_localhost";
		$connectionsIds["For_Approval_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["For_Checking_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["payment_method"] = "erp_test3_at_localhost";
		$connectionsIds["attendance_summary_dashboard_report"] = "erp_test3_at_localhost";
		$connectionsIds["attendance_dashboard_report"] = "erp_test3_at_localhost";
		$connectionsIds["post_attendance"] = "erp_test3_at_localhost";
		$connectionsIds["announcement"] = "erp_test3_at_localhost";
		$connectionsIds["timelog_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["timelog_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["medical"] = "erp_test3_at_localhost";
		$connectionsIds["company"] = "erp_test3_at_localhost";
		$connectionsIds["Violation_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["certifications"] = "erp_test3_at_localhost";
		$connectionsIds["award"] = "erp_test3_at_localhost";
		$connectionsIds["examination"] = "erp_test3_at_localhost";
		$connectionsIds["Medical_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Certification_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Award_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Examination_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["basic_system_audit"] = "erp_test3_at_localhost";
		$connectionsIds["training"] = "erp_test3_at_localhost";
		$connectionsIds["employee_application"] = "erp_test3_at_localhost";
		$connectionsIds["organizations"] = "erp_test3_at_localhost";
		$connectionsIds["location"] = "erp_test3_at_localhost";
		$connectionsIds["cost_center2"] = "erp_test3_at_localhost";
		$connectionsIds["Expiring Employee Recurring Benefits Report"] = "erp_test3_at_localhost";
		$connectionsIds["training_details"] = "erp_test3_at_localhost";
		$connectionsIds["admin_rights"] = "erp_test3_at_localhost";
		$connectionsIds["admin_members"] = "erp_test3_at_localhost";
		$connectionsIds["admin_users"] = "erp_test3_at_localhost";
		$connectionsIds["Loan_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Loan_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["Loanx"] = "erp_test3_at_localhost";
		$connectionsIds["Loanx2"] = "erp_test3_at_localhost";
		$connectionsIds["schedule_import"] = "erp_test3_at_localhost";
		$connectionsIds["process"] = "erp_test3_at_localhost";
		$connectionsIds["process_payroll"] = "erp_test3_at_localhost";
		$connectionsIds["additional_holiday_entry"] = "erp_test3_at_localhost";
		$connectionsIds["HR_Reports"] = "erp_test3_at_localhost";
		$connectionsIds["weekly_schedule"] = "erp_test3_at_localhost";
		$connectionsIds["IT_report_center"] = "erp_test3_at_localhost";
		$connectionsIds["sr_ops_report"] = "erp_test3_at_localhost";
		$connectionsIds["process_payroll_finalpay"] = "erp_test3_at_localhost";
		$connectionsIds["seminar"] = "erp_test3_at_localhost";
		$connectionsIds["seminar_details"] = "erp_test3_at_localhost";
		$connectionsIds["Reimbursement_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["Reimbursement_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["holiday_overtime"] = "erp_test3_at_localhost";
		$connectionsIds["holiday_overtime_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["holiday_overtime_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["missing_logs"] = "erp_test3_at_localhost";
		$connectionsIds["Missing_Logs_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["Missing_Logs_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["flexben"] = "erp_test3_at_localhost";
		$connectionsIds["cut_off"] = "erp_test3_at_localhost";
		$connectionsIds["flexben_type"] = "erp_test3_at_localhost";
		$connectionsIds["Flexben_for_checking"] = "erp_test3_at_localhost";
		$connectionsIds["Flexben_for_approval"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_ticketing"] = "erp_test3_at_localhost";
		$connectionsIds["payroll_ticketing(Open)"] = "erp_test3_at_localhost";
		$connectionsIds["job_grade"] = "erp_test3_at_localhost";
		$connectionsIds["level"] = "erp_test3_at_localhost";
		$connectionsIds["Payroll Generation Per Department Pie"] = "erp_test3_at_localhost";
		$connectionsIds["Payroll Generation"] = "erp_test3_at_localhost";
		$connectionsIds["Overtime_approver1"] = "erp_test3_at_localhost";
		$connectionsIds["Approver1_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Overtime_approver2"] = "erp_test3_at_localhost";
		$connectionsIds["Overtime_approver3"] = "erp_test3_at_localhost";
		$connectionsIds["Overtime_approver4"] = "erp_test3_at_localhost";
		$connectionsIds["Approver2_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Approver3_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Approver4_Dashboard"] = "erp_test3_at_localhost";
		$connectionsIds["Leave_approver1"] = "erp_test3_at_localhost";
		$connectionsIds["Leave_approver2"] = "erp_test3_at_localhost";
		$connectionsIds["Leave_approver3"] = "erp_test3_at_localhost";
		$connectionsIds["Leave_approver4"] = "erp_test3_at_localhost";
		$connectionsIds["Change_Time_Schedule_approver1"] = "erp_test3_at_localhost";
		$connectionsIds["Change_Time_Schedule_approver2"] = "erp_test3_at_localhost";
		$connectionsIds["Change_Time_Schedule_approver3"] = "erp_test3_at_localhost";
		$connectionsIds["Change_Time_Schedule_approver4"] = "erp_test3_at_localhost";
		$connectionsIds["Official_Business_approver1"] = "erp_test3_at_localhost";
		$connectionsIds["Official_Business_approver2"] = "erp_test3_at_localhost";
		$connectionsIds["Official_Business_approver3"] = "erp_test3_at_localhost";
		$connectionsIds["Official_Business_approver4"] = "erp_test3_at_localhost";
		$connectionsIds["Missing_Logs_approver1"] = "erp_test3_at_localhost";
		$connectionsIds["Missing_Logs_approver2"] = "erp_test3_at_localhost";
		$connectionsIds["Missing_Logs_approver3"] = "erp_test3_at_localhost";
		$connectionsIds["Missing_Logs_approver4"] = "erp_test3_at_localhost";
		$connectionsIds["Holiday_Overtime_approver1"] = "erp_test3_at_localhost";
		$connectionsIds["Holiday_Overtime_approver2"] = "erp_test3_at_localhost";
		$connectionsIds["Holiday_Overtime_approver3"] = "erp_test3_at_localhost";
		$connectionsIds["Holiday_Overtime_approver4"] = "erp_test3_at_localhost";
		$connectionsIds["year_end_pto_conversion"] = "erp_test3_at_localhost";
		$connectionsIds["cto"] = "erp_test3_at_localhost";
		$connectionsIds["pto_allowed_balance"] = "erp_test3_at_localhost";
		$connectionsIds["cto_approver1"] = "erp_test3_at_localhost";
		$connectionsIds["cto_approver2"] = "erp_test3_at_localhost";
		$connectionsIds["cto_approver3"] = "erp_test3_at_localhost";
		$connectionsIds["cto_approver4"] = "erp_test3_at_localhost";
		$connectionsIds["Change_Time_Schedule_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Overtime_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Leave_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Official_Business_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Missing_Logs_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Holiday_Overtime_approval"] = "erp_test3_at_localhost";
		$connectionsIds["cto_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Flexben_approval"] = "erp_test3_at_localhost";
		$connectionsIds["cancelled_process_payroll"] = "erp_test3_at_localhost";
		$connectionsIds["Flexben_HR_approval"] = "erp_test3_at_localhost";
		$connectionsIds["ip_restriction"] = "erp_test3_at_localhost";
		$connectionsIds["import_payroll_entry"] = "erp_test3_at_localhost";
		$connectionsIds["offsetting"] = "erp_test3_at_localhost";
		$connectionsIds["Offset_approval"] = "erp_test3_at_localhost";
		$connectionsIds["Cancel_Approved_Flexben"] = "erp_test3_at_localhost";

		$this->_tablesConnectionIds = &$connectionsIds;
	}

	/**
	 * Check if It's possible to add to one table's sql query
	 * an sql subquery to another table.
	 * Access doesn't support subqueries from the same table as main.
	 * @param String dataSourceTName1
	 * @param String dataSourceTName2
	 * @return Boolean
	 */
	public function checkTablesSubqueriesSupport( $dataSourceTName1, $dataSourceTName2 )
	{
		$connId1 = $this->_tablesConnectionIds[ $dataSourceTName1 ];
		$connId2 = $this->_tablesConnectionIds[ $dataSourceTName2 ];

		if( $connId1 != $connId2 )
			return false;

		if( $this->_connectionsData[ $connId1 ]["dbType"] == nDATABASE_Access && $dataSourceTName1 == $dataSourceTName2 )
			return false;

		return true;
	}

	/**
	 * Close db connections
    */
	function CloseConnections()
	{
		foreach( $this->cache as $connection )
		{
			if( $connection )
				$connection->close();
		}
	}
}
?>